EmbyPy Folders
=====================

.. automodule:: embypy.objects
   :show-inheritance:

.. autosummary::
   Folder.child_count
   Folder.cumulative_run_time
   Folder.items

   Playlist.songs
   Playlist.add_items
   Playlist.remove_items

   BoxSet.movies
   BoxSet.series

   MusicAlbum.album_artists
   MusicAlbum.artists
   MusicAlbum.songs

   MusicArtist.albums
   MusicArtist.songs

   Season.index_number
   Season.played_percentage
   Season.episodes
   Season.series

   Series.status
   Series.air_days
   Series.air_time
   Series.premiere_date
   Series.seasons
   Series.episodes

   GameSystem

.. autoclass:: Folder
   :members:

.. autoclass:: Playlist
   :members:

.. autoclass:: BoxSet
   :members:

.. autoclass:: Series
   :members:

.. autoclass:: Season
   :members:

.. autoclass:: MusicArtist
   :members:

.. autoclass:: MusicAlbum
   :members:

.. autoclass:: GameSystem
   :members:
